***************************
 What's New in Pylint 2.13
***************************

.. include:: ../../full_changelog_explanation.rst
.. include:: ../../summary_explanation.rst

.. toctree::
   :maxdepth: 2

   summary.rst
   full.rst
